html

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 4, 2019 License: GPL-3.0 Imports: 6 Imported by: 0

README

Wraparound HTML

HTML Export for Wrap, uses Wraparound CSS to bring your sreen- or stageplay to the browser.

For more information see the wiki or if there is a bug you would like to report or an idea to suggest you can do that here.

Documentation

Index

Constants

This section is empty.

Variables

var Production = false

Production makes the export module add scene numbers

var URLToCSS = "https://cdn.jsdelivr.net/gh/wraparound/css@1.1/"

URLToCSS contains the path to the Wraparound (or your) CSS.

Functions

func MakeHTML

func MakeHTML(script *ast.Script, pathToFile string) error

MakeHTML writes the output of WriteHTML() to a file

func MakeHTMLPage

func MakeHTMLPage(script *ast.Script, pathToFile string) error

MakeHTMLPage writes the output of WriteHTMLPage() to a file

func WriteHTML

func WriteHTML(script *ast.Script, writer io.Writer)

WriteHTML writes a script in HTML format to a *io.Writer

func WriteHTMLPage

func WriteHTMLPage(script *ast.Script, writer io.Writer)

WriteHTMLPage writes the script as html page to a *io.Writer.

Types

This section is empty.

Jump to