Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Default = English
Default language is English
var DutchTranslation = Translation{ Language: Dutch, SceneTags: []string{ "int ", "ext ", "est ", "int./ext ", "int/ext ", "i/e ", "int. ", "ext. ", "est. ", "int./ext. ", "int/ext. ", "i/e. ", "bin ", "bui ", "bin./bui ", "open ", "bin/bui ", "bi/bu ", "bin. ", "bui. ", "bin./bui. ", "open. ", "bin/bui. ", "bi/bu. ", }, StageplaySceneTags: []string{ "scene ", "scène ", }, TransitionTags: []string{ " TO:", " NAAR:", }, BeginActTags: []string{ "BEDRIJF ", }, EndActTags: []string{ "EINDE BEDRIJF ", "EINDE VAN BEDRIJF ", }, More: "(MEER)", Contd: "(VERDER)", }
DutchTranslation is the Dutch translation of Wrap
var EnglishTranslation = Translation{ Language: English, SceneTags: []string{ "int ", "ext ", "est ", "int./ext ", "int/ext ", "i/e ", "int. ", "ext. ", "est. ", "int./ext. ", "int/ext. ", "i/e. ", }, StageplaySceneTags: []string{ "scene ", }, TransitionTags: []string{ " TO:", }, BeginActTags: []string{ "ACT ", }, EndActTags: []string{ "END OF ACT ", }, More: "(MORE)", Contd: "(CONT'D)", }
EnglishTranslation is the English translation of Wrap
var FrenchTranslation = Translation{ Language: French, SceneTags: []string{ "int ", "ext ", "est ", "int./ext ", "int/ext ", "i/e ", "int. ", "ext. ", "est. ", "int./ext. ", "int/ext. ", "i/e. ", }, StageplaySceneTags: []string{ "scene ", "scène ", }, TransitionTags: []string{ " TO:", " A:", " À:", }, BeginActTags: []string{ "ACTE ", }, EndActTags: []string{ "FIN D'ACTE ", "FIN D' ACTE ", }, More: "(PLUS)", Contd: "(SUITE)", }
FrenchTranslation is the French translation of Wrap
var GermanTranslation = Translation{ Language: German, SceneTags: []string{ "int ", "ext ", "est ", "int./ext ", "int/ext ", "i/e ", "int. ", "ext. ", "est. ", "int./ext. ", "int/ext. ", "i/e. ", "etabl ", "etabl. ", }, StageplaySceneTags: []string{ "szene ", }, TransitionTags: []string{ " TO:", " ZU:", }, BeginActTags: []string{ "AKT ", }, EndActTags: []string{ "ENDE DES AKTS ", "ENDE DES AKTES ", }, More: "(MEHR)", Contd: "(FORTGES.)", }
GermanTranslation is the German translation of Wrap
Functions ¶
This section is empty.
Types ¶
type Language ¶
type Language byte
Language represents a supported language
func GetLanguage ¶
GetLanguage allows to convert aliases to a Language defaults to Default
func (Language) String ¶
String allows us to convert a Language to it's standard name, panics when language unknown
func (Language) Translation ¶
func (lang Language) Translation() Translation
Translation gives the translation for the language, panics when no translation available
Click to show internal directories.
Click to hide internal directories.