parser

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2018 License: GPL-3.0 Imports: 10 Imported by: 0

README

Wraparound Parser

This parser transforms a Wrap or Fountain file into a syntax tree which we can use in the export modules.

For more information see the wiki or if there is a bug you would like to report or an idea to suggest you can do that here.

Documentation

Index

Constants

This section is empty.

Variables

var UseWrapExtensions = false

UseWrapExtensions is a flag to show wheter we are using the Wrap extentions or not. The user of this library can change the flag.

Functions

func ParseFile

func ParseFile(filename string) (*ast.Script, error)

ParseFile parses directly from a file path.

func ParseString

func ParseString(script string) (*ast.Script, error)

ParseString parses a string.

func ParseText

func ParseText(text []string) (*ast.Script, error)

ParseText parses a list of strings.

func Parser

func Parser(input io.Reader) (*ast.Script, error)

Parser parses an io.Reader

Types

This section is empty.

Jump to