pdf

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2018 License: GPL-3.0 Imports: 15 Imported by: 0

README

Wraparound PDF

PDF export for Wrap.

For more information see the wiki or if there is a bug you would like to report or an idea to suggest you can do that here.

Documentation

Index

Constants

This section is empty.

Variables

var AddSceneNumbers = true

AddSceneNumbers makes the export module add scene numbers

var SelectedFont = Auto

SelectedFont is the font to be used during export, Auto by default

Functions

func MakePDF

func MakePDF(script *ast.Script, pathToFile string) error

MakePDF writes the PDF to a file

func WritePDF added in v0.1.6

func WritePDF(script *ast.Script, writer io.Writer) error

WritePDF writes the PDF to a writer

Types

type SelectableFont added in v0.2.0

type SelectableFont int

SelectableFont are fonts that the PDF export can use

const (
	Auto SelectableFont = iota
	CourierPrime
	CourierNew
	FreeMono
)

List of selectable fonts

Jump to