Documentation
¶
Index ¶
- func LinesToString(lines []Line) string
- type Action
- type BeginAct
- type Cell
- type CenteredText
- type Dialogue
- type DualDialogue
- type Element
- type ElementType
- type EndAct
- type Line
- type Lyrics
- type Note
- type PageBreak
- type Parenthetical
- type Scene
- type Script
- type Section
- type Speech
- type Synopsis
- type Transition
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LinesToString ¶ added in v0.1.5
LinesToString gets a string representation of a list of strings
Types ¶
type Cell ¶ added in v0.1.5
Cell contains richtext
type CenteredText ¶
type CenteredText []Line
CenteredText type.
func (CenteredText) Equals ¶ added in v0.3.0
func (centeredtext CenteredText) Equals(other Element) bool
Equals checks if an Element is the same CenteredText
type DualDialogue ¶
DualDialogue type.
func (DualDialogue) Equals ¶ added in v0.3.0
func (dualdialogue DualDialogue) Equals(other Element) bool
Equals checks if an Element is the same DualDialogue
type ElementType ¶
type ElementType byte
ElementType is another representation of an elements type
const ( TScene ElementType = iota TBeginAct TEndAct TAction TDialogue TDualDialogue TLyrics TTransition TCenteredText TPageBreak TSection TSynopsis TNote TNone )
Defines the different ElementTypes
func GetElementType ¶
func GetElementType(elem Element) ElementType
GetElementType returns the type of element as a lowercase string and "TNone" if unknown.
type Line ¶ added in v0.1.5
type Line []Cell
Line a line of richtext cells
func (Line) StringBuffer ¶ added in v0.1.5
StringBuffer returns a buffer containing the contents of the line
type Parenthetical ¶
type Parenthetical []Line
Parenthetical type
func (Parenthetical) Equals ¶ added in v0.3.0
func (parenthetical Parenthetical) Equals(other Element) bool
Equals checks if an Element is the same Parenthetical
type Transition ¶
type Transition []Line
Transition type.
func (Transition) Equals ¶ added in v0.3.0
func (transition Transition) Equals(other Element) bool
Equals checks if an Element is the same Transition