Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var UseWrapExtensions = false
UseWrapExtensions is a flag to show wheter we are using the Wrap extentions or not. The user of this library can change the flag.
Functions ¶
func ParseString ¶
ParseString parses a string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.