pdf

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2018 License: GPL-3.0 Imports: 18 Imported by: 0

README

Wraparound PDF

PDF export for Wrap.

For more information see the wiki or if there is a bug you would like to report or an idea to suggest you can do that here.

Documentation

Index

Constants

This section is empty.

Variables

var AddSceneNumbers = true

AddSceneNumbers makes the export module add scene numbers

Functions

func MakePDF

func MakePDF(script *ast.Script) (*gopdf.GoPdf, error)

MakePDF creates a PDF file structure from a script.

func WritePDFFile

func WritePDFFile(script *ast.Script, pathToFile string) error

WritePDFFile writes the output of MakePDF()

Types

This section is empty.

Jump to